<?php
class Blogs extends MY_Front_Controller{
    public function __construct(){
        parent::__construct();
        $this->load->model('BlogsModel', 'blogsModel', true);
        $this->load->library('pagination');
    }
    public function index(){
        $config['base_url']    = base_url() . 'blogs/index';
        $config['total_rows']  = $this->blogsModel->blogsCountUser();
        $config['per_page']    = 7;
        $config['uri_segment'] = 3;
        $config['next_link']   = 'Next';
        $config['prev_link']   = 'Previous';
        $this->pagination->initialize($config);
        $page                  = ($this->uri->segment(3)) ? $this->uri->segment(3) : 0;
        $data                  = array(
            'view'       => 'allBlogs',
            'menu'       => $this->menu,
            'blogs'      => $this->blogsModel->getUserBlogs($config['per_page'], $page),
            'votesCount' => $this->blogsModel->getVotesForBlogs(),
            'links'      => $this->pagination->create_links()
        );
        $this->load->view('template', $data);
    }
    public function viewBlog(){
        $blogId       = get('token');
        $comments     = $this->blogsModel->getAllComments($blogId);
        $commentsView = $this->listComments(0, $comments);
        $blogData     = $this->blogsModel->getBlogById($blogId);
        $data         = array(
            'view'       => 'viewBlog',
            'allBlogs'   => $this->blogsModel->getAllBlogs(),
            'menu'       => $this->menu,
            'votesCount' => $this->blogsModel->getVotesForBlogs(),
            'blogData'   => $blogData,
            'comments'   => $commentsView
        );
        $this->load->view('template', $data);
    }
    public function voteBlog(){
        $user_sess_id = $this->session->userdata('user_id');
        if(empty($user_sess_id)){
            $message = array('type' => 'login');
            echo json_encode($message);
            return false;
        }
        $vtype                = post('vtype');
        $blogId               = decrypt(post('bId'));
        $message              = $this->blogsModel->addUpdateVote($vtype, $blogId, '');
        $votesData            = $this->blogsModel->getVotesForBlogs($blogId);
        $message['upvotes']   = $message['downvotes'] = 0;
        if(!empty($votesData)){
            foreach($votesData[$blogId] as $k => $vote){
                if(isset($vote->vote_type) && $vote->vote_type == 'upvote'){
                    $message['upvotes'] = $vote->votes_count;
                }
                if(isset($vote->vote_type) && $vote->vote_type == 'downvote'){
                    $message['downvotes'] = $vote->votes_count;
                }
            }
        }
        echo json_encode($message);
    }
    public function postComment(){
        $user_sess_id = $this->session->userdata('user_id');
        if(empty($user_sess_id)){
            $message = array('type' => 'login');
            echo json_encode($message);
            return false;
        }
        $comment = post('userComment');
        $parent  = (int) post('parent');
        $blogId  = post('blogId');
        $approved = ($this->approval_flag_home[12] == 'y') ?  'n': 'y' ;
        $insData = array(
            'comment_id'   => decrypt(post('commentId')),
            'blog_id'      => $blogId,
            'comment'      => $comment,
            'user_id'      => $this->session->userdata('user_id'),
            'parent'       => $parent,
            'approved'     => $approved,
            'comment_date' => date("Y-m-d H:i:s"),
            'deleted'      => 'n'
        );
        $message = $this->blogsModel->saveComment($insData);
        $this->saveHierarchy($parent, $message['comment_id']);
        echo json_encode($message);
    }
    public function saveHierarchy($parent, $cmnt_id){
        if($parent == 0){
            $hierarchy = $cmnt_id;
            $depth     = 1;
        }else{
            $getParent       = $this->blogsModel->getCommentById($parent);
            $parentHierarchy = $getParent->hierarchy;
            $hierarchy       = $cmnt_id . "," . $parentHierarchy;
            $count           = count(explode(',', $hierarchy));
            $depth           = $count;
        }
        $insHierarchy = array(
            'hierarchy' => $hierarchy,
            'depth'     => $depth
        );
        $this->blogsModel->saveHierarchy($insHierarchy, array('comment_id' => $cmnt_id));
    }
    public function listComments($parent, $comments){
        $commentsView = "";
        if(!empty($comments['parents'][$parent])){
            $commentsView .= "<ul>";
            foreach($comments['parents'][$parent] as $itemId){
                $editLink    = "";
                $deleteLink  = "";
                $likeLink    = "";
                $dislikeLink = "";
                $commentText = "";
                $replyLink   = "";
                $cmnt_time   = find_diff_comment($comments['items'][$itemId]->comment_date, date("Y-m-d H:i:s"));
                if($comments['items'][$itemId]->deleted == 'n'){
                    if(($comments['items'][$itemId]->approved == 'n' || $comments['items'][$itemId]->approved == 'y') && $this->session->userdata('user_id') == $comments['items'][$itemId]->user_id){
                        $commentText = $comments['items'][$itemId]->comment . "(by: " . $comments['items'][$itemId]->name . " | " . $cmnt_time . ")";
                        $likeLink    = "<a href='javascript:void(0)' c_data='" . $comments['items'][$itemId]->comment_id . "' type='upvote' class='voteComment'><i class='fa fa-thumbs-up'></i></a><span class='upcount'>" . $comments['items'][$itemId]->up . "</span>";
                        $dislikeLink = "<a href='javascript:void(0)' c_data='" . $comments['items'][$itemId]->comment_id . "' type='downvote' class='voteComment'><i class='fa fa-thumbs-down'></i></a><span class='downcount'>" . $comments['items'][$itemId]->down . "</span>";
                        $replyLink   = "<a href='javascript:void(0)' class='replyClick' />Reply</a>";
                        $deleteLink  = "<a href='javascript:void(0)' class='deleteComment' c_data='" . $comments['items'][$itemId]->comment_id . "' />Delete</a>";
                        $editLink    = "<a href='javascript:void(0)' c_data='" . $comments['items'][$itemId]->comment_id . "' class='editLink' />Edit</a>";
                    }
                    if($comments['items'][$itemId]->approved == 'y' && $this->session->userdata('user_id') != $comments['items'][$itemId]->user_id){
                        $commentText = $comments['items'][$itemId]->comment . "(by: " . $comments['items'][$itemId]->name . " | " . $cmnt_time . ")";
                        $likeLink    = "<a href='javascript:void(0)' c_data='" . $comments['items'][$itemId]->comment_id . "' type='upvote' class='voteComment'><i class='fa fa-thumbs-up'></i></a><span class='upcount'>" . $comments['items'][$itemId]->up . "</span>";
                        $dislikeLink = "<a href='javascript:void(0)' c_data='" . $comments['items'][$itemId]->comment_id . "' type='downvote' class='voteComment'><i class='fa fa-thumbs-down'></i></a><span class='downcount'>" . $comments['items'][$itemId]->down . "</span>";
                        $replyLink   = "<a href='javascript:void(0)' class='replyClick' />Reply</a>";
                    }
                }else{
                    $commentText = "<span style='color:#babcc1'>This comment was deleted.</span>";
                }
                if(empty($comments['parents'][$itemId])){
                    $commentsView .= "<li><span class='commentText'>" . $commentText . "</span>";
                    $commentsView .= "<div class='editComment' id='editComment'>"
                        . "<form name='updateComment' id='updateComment'>"
                        . "<textarea name='newComment'>" . $comments['items'][$itemId]->comment . "</textarea>"
                        . "<input type='hidden' name='c_data' value='" . $comments['items'][$itemId]->comment_id . "'/> "
                        . "<button class='btn gradient-bg mr-2' type='submit' id='updateComment'>Update</button>"
                        . "</form>"
                        . "</div>";
                    $commentsView .= "<div class='row'>"
                        . $replyLink
                        . $editLink
                        . $deleteLink
                        . "&nbsp;&nbsp;&nbsp; " . $likeLink
                        . "&nbsp;&nbsp;&nbsp; " . $dislikeLink
                        . "<div id='replyForm' style='display:none;'>"
                        . "<form class='form' name='addUserComment' id='addUserComment'>"
                        . "<div class='form-group'>"
                        . "<input type='hidden' name='parent' value='" . $comments['items'][$itemId]->comment_id . "' id='parent' /> "
                        . "<textarea name='userComment' id='userComment' placeholder='Write your comment here' ></textarea><br/>"
                        . "<input class='btn gradient-bg mr-2' type='submit' name='commentSubmit' id='commentSubmit' value='Post' />"
                        . "</div>"
                        . "</form>"
                        . "</div>"
                        . "</div>"
                        . "</li>";
                }
                if(!empty($comments['parents'][$itemId])){
                    $commentsView .= "<li><span class='commentText'>" . $commentText . "</span>";
                    $commentsView .= "<div class='editComment' id='editComment'>"
                        . "<form name='updateComment' id='updateComment'>"
                        . "<textarea name='newComment'>" . $comments['items'][$itemId]->comment . "</textarea>"
                        . "<input type='hidden' name='c_data' value='" . $comments['items'][$itemId]->comment_id . "'/> "
                        . "<button type='submit' id='updateComment'>Update</button>"
                        . "</form>"
                        . "</div>";
                    $commentsView .= "<div class='row'>"
                        . $replyLink
                        . $editLink
                        . $deleteLink
                        . "&nbsp;&nbsp;&nbsp; " . $likeLink
                        . "&nbsp;&nbsp;&nbsp; " . $dislikeLink
                        . "<div id='replyForm' style='display:none;'>"
                        . "<form class='form' name='addUserComment' id='addUserComment'>"
                        . "<div class='form-group'>"
                        . "<input type='hidden' name='parent' value='" . $comments['items'][$itemId]->comment_id . "' id='reply' />"
                        . "<textarea name='userComment' id='userComment' placeholder='Write your comment here' ></textarea><br/>"
                        . "<input type='submit' name='commentSubmit' id='commentSubmit' value='Post' />"
                        . "</div>"
                        . "</form>"
                        . "</div>"
                        . "</div>";
                    $commentsView .= $this->listComments($itemId, $comments);
                    $commentsView .= "</li>";
                }
            }
            $commentsView .= "</ul>";
        }
        return $commentsView;
    }
    public function delComment(){
        $cmnt_id = post('cmnt_id');
        $this->blogsModel->deleteComment($cmnt_id);
        $message = array('type' => 'success');
        echo json_encode($message);
    }
    public function voteComment(){
        $user_sess_id = $this->session->userdata('user_id');
        if(empty($user_sess_id)){
            $message = array('type' => 'login');
            echo json_encode($message);
            return false;
        }
        $type                 = post('type');
        $cmnt_id              = post('cmnt_id');
        $message              = $this->blogsModel->addUpdateVote($type, '', $cmnt_id);
        $votesData            = $this->blogsModel->getVotesForComments($cmnt_id);
        $message['upvotes']   = $message['downvotes'] = 0;
        if(!empty($votesData[$cmnt_id])){
            foreach($votesData[$cmnt_id] as $k => $vote){
                if(isset($vote->vote_type) && $vote->vote_type == 'upvote'){
                    $message['upvotes'] = $vote->votes_count;
                }
                if(isset($vote->vote_type) && $vote->vote_type == 'downvote'){
                    $message['downvotes'] = $vote->votes_count;
                }
            }
        }
        echo json_encode($message);
    }
    public function addNewBlog(){
//        pre($this->approval_flag_home);
        $data = array(
            'view'       => 'addBlog',
            'allEvents'  => $this->allEvents,
            'menu'       => $this->menu,
        );
        $this->load->view('template', $data);
    }
    public function uploadBlogImage(){
        $url         = $_SERVER['REQUEST_URI']; //returns the current URL
        $parts       = explode('/', $url);
        $actual_link = $_SERVER['SERVER_NAME'];
        for($i = 0; $i < count($parts) - 1; $i++){
            $actual_link .= $parts[$i] . "/";
        }
        $target_dir  = SITE_ROOT . "skin/images/blogImages/";
        $imgName     = uniqid() . basename($_FILES["file"]["name"]);
        $target_file = $target_dir . $imgName;

        if(move_uploaded_file($_FILES["file"]["tmp_name"], $target_file)){
            $rs  = SITE_URL . "skin/images/blogImages/" . $imgName;
            $arr = array(
                'url' => $rs
            );
        }else{
            $arr = array(
                'url' => null
            );
        }
        echo json_encode($arr);
    }
    public function saveBlog(){
        $user_sess_id = $this->session->userdata('user_id');
        if(empty($user_sess_id)){
            $message = array('type' => 'login');
            echo json_encode($message);
            return false;
        }
        $publish = 'n';
        if($this->approval_flag_home[11] == 'n'){
            $publish = 'y';
        }
        $blogTitle = strtolower(post('blogTitle'));
        $blogKey   = preg_replace('#[ -]+#', '-', trim($blogTitle));
        $insData   = array(
            'blog_key'      => $blogKey,
            'title'         => post('blogTitle'),
            'content'       => post('blogContent'),
            'creation_date' => date("Y-m-d"),
            'publish'       => $publish,
            'is_homepage'   => 'n',
            'created_by'    => $this->session->userdata('user_id')
        );
        $message   = $this->blogsModel->insertUpdateBlog($insData);
        if($message['type'] == 'error'){
            echo json_encode($message);
            exit;
        }
        setSessionMsg($message['type'], $message['message']);
        echo json_encode($message);
    }
    public function allBlogs(){
        $config['base_url']    = base_url() . 'blogs/allBlogs/index';
        $config['total_rows']  = $this->blogsModel->blogsCountAll();
        $config['per_page']    = 5;
        $config['uri_segment'] = 4;
        $config['next_link']   = 'Next';
        $config['prev_link']   = 'Previous';
        $this->pagination->initialize($config);
        $page                  = ($this->uri->segment(4)) ? $this->uri->segment(4) : 0;
        $data                  = array(
            'view'       => 'allBlogs',
            'menu'       => $this->menu,
            'blogs'      => $this->blogsModel->getAllBlogs($config['per_page'], $page),
            'votesCount' => $this->blogsModel->getVotesForBlogs(),
            'links'      => $this->pagination->create_links()
        );
        $this->load->view('template', $data);
    }
    public function updateComment(){
        $comment_id = post('c_data');
        $comment    = post('newComment');
        $this->blogsModel->updateComment(array('comment' => $comment), array('comment_id' => $comment_id));
        echo json_encode(array('type' => 'success'));
    }
}
?>