<?php
class BlogsModel extends CI_Model{
    public function __construct(){
        parent::__construct();
    }
    public function getAllBlogs($num = 0, $offset = ''){
        $this->db->select('b.blog_id, b.blog_key, b.title, b.content, b.created_by, DATE_FORMAT(b.creation_date, "%b %D, %Y") as creation_date, concat_ws(" ", u.first_name, u.last_name) as name')
            ->from(DB_PREFIX.'blogs as b')
            ->join(DB_PREFIX.'users as u', 'b.created_by=u.user_id')
            ->where('b.publish', 'y')
            ->limit($num, $offset)
            ->order_by('b.creation_date', 'ASC');
        $result = $this->db->get();
        if($result->num_rows() > 0){
            foreach($result->result() as $row){
                $blogsData[$row->blog_id] = $row;
            }
            return $blogsData;
        }
        return array();
    }
    public function blogsCountUser(){
        $this->db->select('*');
        $this->db->where('publish', 'y');
        $this->db->where('created_by', $this->session->userdata('user_id'));
        $res = $this->db->get('charity_blogs');
        return $res->num_rows();
    }
    public function blogsCountAll(){
        $this->db->select('*');
        $this->db->where('publish', 'y');
        $res = $this->db->get('charity_blogs');
        return $res->num_rows();
    }
    public function getUserBlogs($num = 0, $offset = ''){
        $this->db->select('b.blog_id, b.blog_key, b.title, b.content, b.created_by, DATE_FORMAT(b.creation_date, "%b %D, %Y") as creation_date, concat_ws(" ", u.first_name, u.last_name) as name')
            ->from(DB_PREFIX.'blogs as b')
            ->join(DB_PREFIX.'users as u', 'b.created_by=u.user_id')
            ->where(array('b.created_by' => $this->session->userdata('user_id')))
            ->limit($num, $offset);
        $result  = $this->db->get();
        if($result->num_rows() > 0){
            foreach($result->result() as $row){
                $blogsData[$row->blog_id] = $row;
            }
            return $blogsData;
        }
        return array();
    }
    public function getVotesForBlogs($blog_id = ''){
        $votesData = array();
        $where     = '';
        if(!empty($blog_id)){
            $where = " AND blog_id=" . $blog_id;
        }
        $query  = "SELECT count(*) as votes_count,blog_id,vote_type FROM charity_blog_votes where vote_type='upvote' " . $where . " group by blog_id UNION ALL "
            . " SELECT count(*) as votes_count,blog_id,vote_type FROM charity_blog_votes where vote_type='downvote' " . $where . " group by blog_id order by blog_id";
        $result = $this->db->query($query);
        if($result->num_rows() > 0){
            foreach($result->result() as $row){
                $votesData[$row->blog_id][] = $row;
            }
        }
        return $votesData;
    }
    public function getVotesForComments($comment_id = ''){
        $votesData = array();
        $where     = '';
        if(!empty($blog_id)){
            $where = " AND blog_id=" . $comment_id;
        }
        $query  = "SELECT count(*) as votes_count,comment_id,vote_type FROM charity_comment_votes where vote_type='upvote' " . $where . " group by comment_id UNION ALL "
            . " SELECT count(*) as votes_count,comment_id,vote_type FROM charity_comment_votes where vote_type='downvote' " . $where . " group by comment_id order by comment_id";
        $result = $this->db->query($query);
        if($result->num_rows() > 0){
            foreach($result->result() as $row){
                $votesData[$row->comment_id][] = $row;
            }
        }
        return $votesData;
    }
    public function getBlogById($blog_id){
        $query  = "SELECT blog_id, blog_key, title, content from charity_blogs WHERE blog_id='" . $blog_id . "'";
        $result = $this->db->query($query);
        if($result->num_rows() > 0){
            return $result->first_row();
        }
        return array();
    }
    public function addUpdateVote($type, $blog_id = '', $comment_id = ''){
        $getVote = $this->getVoteByUserId($blog_id, $comment_id);
        if($getVote){
            if($getVote->vote_type == $type){
                $this->removeVote($blog_id, $comment_id);
            }else{
                $this->updateVote($type, $blog_id, $comment_id);
            }
        }else{
            $this->addVote($type, $blog_id, $comment_id);
        }
        return array('type' => 'success');
    }
    public function getVoteByUserId($blog_id = '', $comment_id = ''){
        $user_id = $this->session->userdata('user_id');
        if($comment_id == ''){
            $where = array(
                'blog_id' => $blog_id,
                'user_id' => $this->session->userdata('user_id')
            );
            $this->db->where($where);
            $res   = $this->db->get('charity_blog_votes');
            if($res->num_rows() > 0){
                return $res->first_row();
            }
            return false;
        }
        if($blog_id == ''){
            $where = array(
                'comment_id' => $comment_id,
                'user_id'    => $this->session->userdata('user_id')
            );
            $this->db->where($where);
            $res   = $this->db->get('charity_comment_votes');
            if($res->num_rows() > 0){
                return $res->first_row();
            }
            return false;
        }
    }
    public function removeVote($blog_id = '', $comment_id = ''){
        if($comment_id == ''){
            $where = array(
                'user_id' => $this->session->userdata('user_id'),
                'blog_id' => $blog_id
            );
            $this->db->where($where);
            $this->db->delete('charity_blog_votes');
        }
        if($blog_id == ''){
            $where = array(
                'user_id'    => $this->session->userdata('user_id'),
                'comment_id' => $comment_id
            );
            $this->db->where($where);
            $this->db->delete('charity_comment_votes');
        }
    }
    public function updateVote($type, $blog_id = '', $comment_id = ''){
        if($comment_id == ''){
            $updData = array(
                'vote_type'          => $type,
                'vote_updation_date' => date("Y-m-d H:i:s")
            );
            $where   = array(
                'user_id' => $this->session->userdata('user_id'),
                'blog_id' => $blog_id
            );
            $this->db->update('charity_blog_votes', $updData, $where);
        }
        if($blog_id == ''){
            $where   = array(
                'user_id'    => $this->session->userdata('user_id'),
                'comment_id' => $comment_id
            );
            $updData = array(
                'vote_type'          => $type,
                'vote_updation_date' => date("Y-m-d H:i:s")
            );
            $this->db->update('charity_comment_votes', $updData, $where);
        }
    }
    public function addVote($type, $blog_id = '', $comment_id = ''){
        if($comment_id == ''){
            $insVote = array(
                'blog_id'   => $blog_id,
                'user_id'   => $this->session->userdata('user_id'),
                'vote_type' => $type,
                'vote_date' => date("Y-m-d H:i:s")
            );
            $this->db->insert('charity_blog_votes', $insVote);
        }
        if($blog_id == ''){
            $insVote = array(
                'comment_id' => $comment_id,
                'user_id'    => $this->session->userdata('user_id'),
                'vote_type'  => $type,
                'vote_date'  => date("Y-m-d H:i:s")
            );
            $this->db->insert('charity_comment_votes', $insVote);
        }
    }
    public function getAllComments($blog_id = ''){
        $comments = array(
            'items'   => array(),
            'parents' => array()
        );
        $where    = "";
        if(!empty($blog_id)){
            $where = " where mbc.blog_id='" . $blog_id . "'";
        }
        $query = "SELECT mbc.comment_id, mbc.comment, mbc.blog_id, mbc.user_id, mbc.approved, mbc.parent, mbc.comment_date, mbc.deleted, "
            . " concat_ws(' ', mu.first_name, mu.last_name) AS name, "
            . "(SELECT SUM(case when vote_type='upvote' then 1 else 0 end) AS upvote "
            . " FROM charity_comment_votes where comment_id = mbc.comment_id) as up, "
            . "(SELECT SUM(case when vote_type='downvote' then 1 else 0 end) AS upvote "
            . " FROM charity_comment_votes where comment_id = mbc.comment_id) as down "
            . " FROM charity_blog_comments AS mbc "
            . " LEFT JOIN charity_users AS mu ON mbc.user_id = mu.user_id " . $where . ""
            . " order by mbc.comment_date DESC ";
        $res   = $this->db->query($query);
        if($res->num_rows() > 0){
            foreach($res->result() as $row){
                $comments['items'][$row->comment_id] = $row;
                $comments['parents'][$row->parent][] = $row->comment_id;
            }
        }
        return $comments;
    }
    public function saveComment($insData){
        $this->db->insert('charity_blog_comments', $insData);
        $comment_id = $this->db->insert_id();
        return array('type' => 'success', 'message' => 'Comment posted successfully.', 'comment_id' => $comment_id);
    }
    public function getCommentById($comment_id){
        $commentData = array();
        $this->db->select('*');
        $this->db->where('comment_id', $comment_id);
        $res         = $this->db->get('charity_blog_comments');
        if($res->num_rows() > 0){
            $commentData = $res->first_row();
        }
        return $commentData;
    }
    public function saveHierarchy($insData, $where){
        $this->db->update('charity_blog_comments', $insData, $where);
    }
    public function deleteComment($comment_id){
        $this->db->update('charity_blog_comments', array('deleted' => 'y'), array('comment_id' => $comment_id));
    }
    public function insertUpdateBlog($insData){
        if($this->checkExistingBlogs($insData)){
            return array('type' => 'error', 'message' => 'Blog with the same title already uploaded.');
        }
        unset($insData['updation_date']);
        unset($insData['updated_by']);
        $this->db->insert('charity_blogs', $insData);
        return array('type' => 'success', 'message' => 'Blog added successfully.');
    }
    public function checkExistingBlogs($data){
        $title = $data['title'];
        $this->db->where("title = '" . $title . "'");
        if(!empty($blogId)){
            $this->db->where('blog_id !=', $blogId);
        }
        $result = $this->db->get('charity_blogs');
        if($result->num_rows() > 0){
            return true;
        }
        return false;
    }
    public function updateComment($updData, $updWhere){
        $updData['comment_update_date'] = date("Y-m-d H:i:s");
        $this->db->update('charity_blog_comments', $updData, $updWhere);
    }
}
?>