<?php
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
class QuestionsModel extends CI_Model{
    public function __construct(){
        parent::__construct();
    }
    public function getAllQuestions(){
        $quesData = array();
        $this->db->select('q.question_id, q.user_id, q.question, q.description, q.approved, q.creation_date as asked_on, concat_ws(" ", mu.first_name, mu.last_name) as asked_by')
            ->from(DB_PREFIX . 'questions as q')
            ->join('charity_users as mu', 'q.user_id=mu.user_id', 'left');
        $res      = $this->db->get();
        if($res->num_rows() > 0){
            foreach($res->result() as $row){
                $quesData[] = $row;
            }
            return $quesData;
        }
        return $quesData;
    }
    public function getParentCategories(){
        $parentCat = array();
        $this->db->select('category_id, category_name');
        $this->db->where('parent', 0);
        $this->db->where('approved', 'y');
        $res       = $this->db->get('charity_categories');
        if($res->num_rows() > 0){
            foreach($res->result() as $row){
                $parentCat[] = $row;
            }
            return $parentCat;
        }
        return $parentCat;
    }
    public function getQuestionById($question_id){
        $this->db->select('question_id, user_id, question, description, approved, is_anonymous');
        $this->db->where('question_id', $question_id);
        $res = $this->db->get(DB_PREFIX . 'questions');
        if($res->num_rows() > 0){
            return $res->first_row();
        }
        return array();
    }
    public function getAnswerById($answer_id){
        $this->db->select('answer_id, question_id, user_id, answer, approved, is_anonymous');
        $this->db->where('answer_id', $answer_id);
        $res = $this->db->get(DB_PREFIX . 'answers');
        if($res->num_rows() > 0){
            return $res->first_row();
        }
        return array();
    }
    public function deleteQuestion($question_id){
        $this->db->where('question_id', $question_id);
        $this->db->delete(DB_PREFIX . 'questions');
    }
    public function changeQuesAppr($question_id, $approved){
        $updData = array(
            'approved'      => $approved,
            'updation_date' => date("Y-m-d H:i:s")
        );
        $this->db->update(DB_PREFIX . 'questions', $updData, array('question_id' => $question_id));
    }
    public function getChildCatByParentId($parent){
        $childCat = array();
        $this->db->select('category_id, category_name');
        $this->db->where('parent', $parent);
        $this->db->where('approved', 'y');
        $res      = $this->db->get('charity_categories');
        if($res->num_rows() > 0){
            foreach($res->result() as $row){
                $row->category_name = ucwords($row->category_name);
                $childCat[]         = $row;
            }
            return $childCat;
        }
        return $childCat;
    }
    public function getParentCategory($category_id = ''){
        if(empty($category_id)){
            return array();
        }
        $this->db->select('category_id, parent, category_name');
        $this->db->where('category_id', $category_id);
        $res = $this->db->get('charity_categories');
        if($res->num_rows() > 0){
            return $res->first_row();
        }
        return array();
    }
    public function addUpdateQuestion($quesData){
        if($this->checkExistingQuestions($quesData)){
            return array('type' => 'error', 'message' => 'Question already exists.');
        }
        $question_id = $quesData['question_id'];
        if(empty($question_id)){
            unset($quesData['updation_date']);
            unset($quesData['updated_by']);
            $this->db->insert(DB_PREFIX . 'questions', $quesData);
            $insQuesId = $this->db->insert_id();
//            echo $this->db->last_query();
            return array('type' => 'success', 'message' => 'Question added successfully.', 'question_id' => $insQuesId);
        }else{
            unset($quesData['creation_date']);
            unset($quesData['user_id']);
            $this->db->update(DB_PREFIX . 'questions', $quesData, array('question_id' => $quesData['question_id']));
            return array('type' => 'success', 'message' => 'Question updated successfully.', 'question_id' => $quesData['question_id']);
        }
    }
    public function checkExistingQuestions($data){
        $question_id = $data['question_id'];
        $question    = $data['question'];
        $this->db->where("question = '" . $question . "'");
        if(!empty($question_id)){
            $this->db->where('question_id !=', $question_id);
        }
        $result = $this->db->get(DB_PREFIX . 'questions');
        if($result->num_rows() > 0){
            return true;
        }
        return false;
    }
    public function getAnswersByQuestionId($question_id){
        $subGrp  = $this->a_sub_group_id[0];
        $access  = $this->a_access[$subGrp];
        $answers = array();
        $this->db->select('a.answer_id, a.user_id, concat_ws(" ", mu.first_name, mu.last_name) as answered_by, a.question_id, a.answer, q.question as question, a.approved, a.creation_date as answered_on, a.is_anonymous')
            ->from(DB_PREFIX . 'answers as a')
            ->join('charity_users as mu', 'a.user_id=mu.user_id', 'inner')
            ->join(DB_PREFIX . 'questions as q', 'q.question_id=a.question_id', 'inner')
            ->where('a.question_id', $question_id)
            ->order_by('a.creation_date');
        $res     = $this->db->get();
        if($res->num_rows() > 0){
            foreach($res->result() as $row){
                $row->answered_on = displayDateTime($row->answered_on);
                $row->answered_by = ucwords($row->answered_by);
                $row->answer_id   = ($access->edit_rights == 'y') ? encrypt($row->answer_id) : '';
                $row->question_id = ($access->edit_rights == 'y') ? encrypt($row->question_id) : '';
                $answers[]        = $row;
            }
            return $answers;
        }
        return $answers;
    }
    public function approveAnswer($answer_id){
        $answerData = $this->getAnswerById($answer_id);
        if($answerData->approved == 'n'){
            $this->db->update(DB_PREFIX . 'answers', array('approved' => 'y'), array('answer_id' => $answer_id));
        }else{
            $this->db->update(DB_PREFIX . 'answers', array('approved' => 'n'), array('answer_id' => $answer_id));
        }
    }
}
?>

