/*
 * Tinymce Initialization
 */
tinymce.init({
    selector: '#blogContent',
    theme: 'modern',
    plugins: [
        'lists charmap code',
    ],
    toolbar1: 'bold italic | alignleft aligncenter alignright alignjustify | bullist numlist | code',
    toolbar2: 'imageupload',
    setup: function (editor) {
        BLOG.uploadImageToServer(editor);
    },
    content_css: SITE_URL + 'js/tinymce/skins/lightgray/content.min.css',
    height: 300,
    menubar: false,
    image_advtab: true,
    branding: false,
    relative_urls: false,
    remove_script_host: false
});
BLOG = {
    uploadImageToServer: function (that) {
        // create input and insert in the DOM
        var inp = $('<input id="tinymce-uploader" type="file" name="pic" accept="image/*" style="display:none">');
        $(that.getElement()).parent().append(inp);
        var parent1 = $(that.getElement()).parent();

        // add the image upload button to the editor toolbar
        that.addButton('imageupload', {
            text: 'Local',
            icon: 'image',
            onclick: function (e) { // when toolbar button is clicked, open file select modal
                inp.trigger('click');
            }
        });

        // when a file is selected, upload it to the server
        inp.on("change", function (e) {
            BLOG.uploadFile(this, that);
        });
    },
    uploadFile: function (that, editor) {
        var file_data = $(that).prop('files')[0];
        var data = new FormData();
        data.append('file', file_data);

        $.ajax({
            url: SITE_URL_ADMIN + 'blogs/uploadBlogImage',
            type: 'POST',
            data: data,
            processData: false, // Don't process the files
            contentType: false, // Set content type to false as jQuery will tell the server its a query string request
            success: function (data, textStatus, jqXHR) {
                data = JSON.parse(data);
                editor.insertContent('<img class="content-img" src="' + data.url + '"/>');
            },
            error: function (jqXHR, textStatus, errorThrown) {
                if (jqXHR.responseText) {
                    errors = JSON.parse(jqXHR.responseText).errors
                    alert('Error uploading image: ' + errors.join(", ") + '. Make sure the file is an image and has extension jpg/jpeg/png.');
                }
            }
        });
    },
    saveUpdateBlog: function (that) {
        $(that).validationEngine(ValidationOption);
        var result = $(that).validationEngine('validate');
        if (!result) {
            return false;
        }
        var formData = $(that).serialize();
        Loader.show();
        $.ajax({
            url: SITE_URL_ADMIN + "blogs/addBlog",
            dataType: "json",
            type: 'POST',
            data: formData,
            success: function (response) {
                Loader.hide();
                if (response.type == 'success') {
//                    AlertMessage.success(response.message);
                    redirect('admin/blogs');
                } else {
                    AlertMessage.error(response.message);
                    return false;
                }
            },
            error: function (error) {
                Loader.hide();
                ajaxError(error);
            }
        });
    },
    deleteBlog: function (that) {
        var bId = $(that).attr('b_data');
        if (confirm('Are you sure you want to delete this blog ? ')) {
            Loader.show();
            $.ajax({
                url: SITE_URL_ADMIN + "blogs/delBlog",
                type: "POST",
                dataType: "json",
                data: {
                    delBid: bId
                },
                success: function (response) {
                    Loader.hide();
                    if (response.type == 'success') {
//                        AlertMessage.success(response.message);
                        redirect('admin/blogs');
                    } else {
                        AlertMessage.error(response.message);
                        return false;
                    }
                }
            });
        }
    },
    updateHomepageStatus: function (blog_id) {
        if (blog_id != '') {
            Loader.show();
            $.ajax({
                url: SITE_URL_ADMIN + "blogs/updHomepageStatus",
                type: "POST",
                dataType: "json",
                data: {
                    blog_id: blog_id
                },
                success: function (response) {
                    Loader.hide();
                    if (response.type == 'success') {
                        redirect('admin/blogs');
                    } else if (response.type == 'invalid_id') {
                        redirect(SITE_URL_ADMIN + 'dashboard');
                    } else {
                        AlertMessage.error(response.message);
                        return false;
                    }
                }
            });
        }
    },
    publishBlog: function (blog_id) {
        if (blog_id != '') {
            Loader.show();
            $.ajax({
                url: SITE_URL_ADMIN + "blogs/publishBlog",
                type: "POST",
                dataType: "json",
                data: {
                    blog_id: blog_id
                },
                success: function (response) {
                    Loader.hide();
                    if (response.type == 'success') {
                        redirect('admin/blogs');
                    } else if (response.type == 'invalid_id') {
                        redirect('admin/dashboard');
                    } else {
                        AlertMessage.error(response.message);
                        return false;
                    }
                }
            });
        }
    }
}
$(document).on('submit', '#addBlog', function (e) {
    e.preventDefault();
    BLOG.saveUpdateBlog(this);
});
$(document).on('click', '#blog_del_btn', function (e) {
    e.preventDefault();
    BLOG.deleteBlog(this);
});
$(document).on('click', '.setHomepage', function (e) {
    e.preventDefault();
    var blog_id = $(this).attr('b_data');
    BLOG.updateHomepageStatus(blog_id);
});
$(document).on('click', '.publishBlog', function (e) {
    e.preventDefault();
    var blog_id = $(this).attr('b_data');
    BLOG.publishBlog(blog_id);
});
$(function () {
    var qryString = window.location.search;
    if (qryString != '') {
        $('#addBlog').removeClass('collapse');
    } else {
        $('#addBlog').addClass('collapse');
    }
    var t = $('#blogsTable').DataTable({
        "serverSide": true,
        "aaSorting": [],
        "ajax": {
            'url': SITE_URL_ADMIN + "blogs_server_script/index",
            'type': 'GET',
        },
        "columns": [
            {"name": "filterBlogId", "orderable": true},
            {"name": "filterBlogTitle", "orderable": true},
            {"name": "filterBlogUploadedBy", "orderable": true},
            {"name": "filterBlogUserType", "orderable": true},
            {"name": "filterBlogStatus", "orderable": true},
            {"name": "filterUpVotes", "orderable": true},
            {"name": "filterDownVotes", "orderable": true},
            {"name": "filterBlogHomepage", "orderable": false},
            {"name": "filterBlogAction", "orderable": false},
        ],
    });
});