/*
 * Tinymce Initialization
 */
tinymce.init({
    selector: '#eventContent',
    theme: 'modern',
    plugins: [
        'lists charmap',
    ],
    toolbar1: 'bold italic | alignleft aligncenter alignright alignjustify | bullist numlist',
    toolbar2: 'imageupload',
    setup: function (editor) {
        EVENT.uploadImageToServer(editor);
    },
    content_css: '../js/tinymce/skins/lightgray/content.min.css',
    height: 300,
    menubar: false,
    image_advtab: true,
    branding: false,
    relative_urls: false,
    remove_script_host: false
});

EVENT = {
    previewEventImages: function (that) {
        var fileList = that.files;
        var anyWindow = window.URL || window.webkitURL;
        $('#eventImagePreview').html('');
        for (var i = 0; i < fileList.length; i++) {
            var objectUrl = anyWindow.createObjectURL(fileList[i]);
            $('#eventImagePreview').append('<img id="vewImg" src="' + objectUrl + '" height="200px" width="400px" />');
            window.URL.revokeObjectURL(fileList[i]);
        }
    },
    uploadImageToServer: function (that) {
        // create input and insert in the DOM
        var inp = $('<input id="tinymce-uploader" type="file" name="pic" accept="image/*" style="display:none">');
        $(that.getElement()).parent().append(inp);
        var parent1 = $(that.getElement()).parent();

        // add the image upload button to the editor toolbar
        that.addButton('imageupload', {
            text: 'Local',
            icon: 'image',
            onclick: function (e) { // when toolbar button is clicked, open file select modal
                inp.trigger('click');
            }
        });

        // when a file is selected, upload it to the server
        inp.on("change", function (e) {
            EVENT.uploadFile(this, that);
        });
    },
    uploadFile: function (that, editor) {
        var file_data = $(that).prop('files')[0];
        var data = new FormData();
        data.append('file', file_data);

        $.ajax({
            url: SITE_URL + 'admin/events/uploadEventImage',
            type: 'POST',
            data: data,
            processData: false, // Don't process the files
            contentType: false, // Set content type to false as jQuery will tell the server its a query string request
            success: function (data, textStatus, jqXHR) {
                data = JSON.parse(data);
                editor.insertContent('<img class="content-img" src="' + data.url + '"/>');
            },
            error: function (jqXHR, textStatus, errorThrown) {
                if (jqXHR.responseText) {
                    errors = JSON.parse(jqXHR.responseText).errors
                    alert('Error uploading image: ' + errors.join(", ") + '. Make sure the file is an image and has extension jpg/jpeg/png.');
                }
            }
        });
    },
    saveUpdateEvent: function (that) {
        var submit_btn = $('#addEventBtn').val();
        if(submit_btn == 'Add') {
            $('#eventImage').attr('data-validation-engine="validate[required]" data-prompt-position="topLeft"');
        }
        $(that).validationEngine(ValidationOption);
        var result = $(that).validationEngine('validate');
        if (!result) {
            return false;
        }
        var formData = new FormData(that);
        Loader.show();
        $.ajax({
            url: SITE_URL_ADMIN + "events/addEvent",
            dataType: "json",
            type: 'POST',
            processData: false,
            contentType: false,
            data: formData,
            success: function (response) {
                Loader.hide();
                if (response.type == 'success') {
//                    AlertMessage.success(response.message);
                    redirect('admin/events');
                } else {
                    AlertMessage.error(response.message);
                }
            },
            error: function (error) {
                Loader.hide();
                ajaxError(error);
            }
        });
    },
    deleteEvent: function (that) {
        var eventId = $(that).attr('token');
        if (confirm('Are you sure you want to delete this event?')) {
            Loader.show();
            $.ajax({
                url: SITE_URL_ADMIN + "events/delEvent",
                type: "POST",
                dataType: "json",
                data: {
                    eventId: eventId
                },
                success: function (response) {
                    Loader.hide();
                    if (response.type == 'success') {
//                        AlertMessage.success(response.message);
                        redirect('admin/events');
                    }
                }
            });
        }
    },
    addMoreFields: function () {
        $('#dateFieldsTemplate').tmpl().appendTo('#appendMoreDateFields');
        EVENT.initDateTimePicker();
        COUNTER++;
    },
    removeFields: function (that) {
        var dateId = $(that).attr('date_id');
        if (dateId != '') {
            // Get event Id token from Query String
            var hashes = window.location.href.slice(window.location.href.indexOf('?') + 1);
            var token = hashes.substr(hashes.indexOf("=") + 1);
            $.ajax({
                url: SITE_URL_ADMIN + "Events/delDate",
                type: "POST",
                dataType: "json",
                data: {
                    dateId: dateId
                },
                success: function (response) {
                    if (response.type == 'success') {
                        COUNTER--;
                        window.location.replace(SITE_URL_ADMIN + "events?token=" + token);
                    }
                }
            });
        } else {
            $(that).closest('.myDateTimeDiv').remove();
            COUNTER--;
        }
    },
    initDateTimePicker: function () {
        //Date picker
        $('.date1').datepicker({
            autoclose: true,
            format: 'mm-dd-yyyy'
        })
        //Timepicker
        $('.time1').timepicker({
            showInputs: false,
            defaultTime: ''
        })
        $('.time2').timepicker({
            showInputs: false,
            defaultTime: ''
        })
    }
}

/*
 * On "submit" listener on the "Add Event" Form.
 */
$(document).on('submit', '#addEvents', function (e) {
    e.preventDefault();
    EVENT.saveUpdateEvent(this);
});
/*
 * Event Deletion
 */
$(document).on('click', '#event_del_btn', function (e) {
    e.preventDefault();
    EVENT.deleteEvent(this);
});
$(document).on('click', '#addMoreDate', function (e) {
    e.preventDefault();
    EVENT.addMoreFields();
});
$(document).on('change', '#eventImage', function () {
    EVENT.previewEventImages(this);
});
$(document).on('click', '#removeDate', function (e) {
    if (COUNTER == 1) {
        alert('At least One Field is Mandatory');
    } else {
        e.preventDefault();
        EVENT.removeFields(this);
    }
});
$(document).ready(function () {
    EVENT.initDateTimePicker();
});
$(function ()
{
    var qryString = window.location.search;
    if(qryString != '') {
        $('#addEvents').removeClass('collapse');
    } else {
        $('#addEvents').addClass('collapse');
    }
});