/*
 * Tinymce Initialization
 */
tinymce.init({
    selector: '#pageContent',
    theme: 'modern',
    plugins: [
        'lists charmap code',
    ],
    toolbar1: 'bold italic | alignleft aligncenter alignright alignjustify | bullist numlist | code',
    toolbar2: 'imageupload',
    setup: function (editor) {
        PAGE.uploadImageToServer(editor);
    },
    content_css: '../js/tinymce/skins/lightgray/content.min.css',
    height: 300,
    menubar: false,
    image_advtab: true,
    branding: false,
    relative_urls: false,
    remove_script_host: false
});

PAGE = {
    uploadImageToServer: function (that) {
        // create input and insert in the DOM
        var inp = $('<input id="tinymce-uploader" type="file" name="pic" accept="image/*" style="display:none">');
        $(that.getElement()).parent().append(inp);
        var parent1 = $(that.getElement()).parent();

        // add the image upload button to the editor toolbar
        that.addButton('imageupload', {
            text: 'Local',
            icon: 'image',
            onclick: function (e) { // when toolbar button is clicked, open file select modal
                inp.trigger('click');
            }
        });

        // when a file is selected, upload it to the server
        inp.on("change", function (e) {
            PAGE.uploadFile(this, that);
        });
    },
    uploadFile: function (that, editor) {
        var file_data = $(that).prop('files')[0];
        var data = new FormData();
        data.append('file', file_data);

        $.ajax({
            url: SITE_URL + 'admin/pages/uploadPageImage',
            type: 'POST',
            data: data,
            processData: false, // Don't process the files
            contentType: false, // Set content type to false as jQuery will tell the server its a query string request
            success: function (data, textStatus, jqXHR) {
                data = JSON.parse(data);
                editor.insertContent('<img class="content-img" src="' + data.url + '"/>');
            },
            error: function (jqXHR, textStatus, errorThrown) {
                if (jqXHR.responseText) {
                    errors = JSON.parse(jqXHR.responseText).errors
                    alert('Error uploading image: ' + errors.join(", ") + '. Make sure the file is an image and has extension jpg/jpeg/png.');
                }
            }
        });
    },
    saveUpdatePage: function(that) {
        $(that).validationEngine(ValidationOption);
        var result = $(that).validationEngine('validate');
        if (!result) {
            return false;
        }
        var formData = $(that).serialize();
        Loader.show();
        $.ajax({
            url: SITE_URL_ADMIN + "pages/addPage",
            dataType: "json",
            type: 'POST',
            data: formData,
            success: function (response) {
                Loader.hide();
                if (response.type == 'success') {
//                    AlertMessage.success(response.message);
                    redirect('admin/pages');
                } else {
                    AlertMessage.error(response.message);
                    return false;
                }
            },
            error: function (error) {
                Loader.hide();
                ajaxError(error);
            }
        });
    },
    deletePage: function(that) {
        var pId = $(that).attr('token');
        if (confirm('Are you sure you want to delete this page ? ')) {
            Loader.show();
            $.ajax({
                url: SITE_URL_ADMIN + "pages/delPage",
                type: "POST",
                dataType: "json",
                data: {
                    delPid: pId
                },
                success: function (response) {
                    Loader.hide();
                    if (response.type == 'success') {
//                        AlertMessage.success(response.message);
                        redirect('admin/pages');
                    }
                }
            });
        }
    }
}
$(document).on('submit', '#addPages', function (e) {
    e.preventDefault();
    PAGE.saveUpdatePage(this);
});
$(document).on('click', '#page_del_btn', function (e) {
    e.preventDefault();
    PAGE.deletePage(this);
});
$(function ()
{
    var qryString = window.location.search;
    if(qryString != '') {
        $('#addPages').removeClass('collapse');
    } else {
        $('#addPages').addClass('collapse');
    }
});

