/*
 * Tinymce Initialization
 */
tinymce.init({
    selector: '#blogContent',
    theme: 'modern',
    plugins: [
        'lists charmap code',
    ],
    toolbar1: 'bold italic | alignleft aligncenter alignright alignjustify | bullist numlist | code',
    toolbar2: 'imageupload',
    setup: function (editor) {
        BLOG.uploadImageToServer(editor);
    },
    content_css: '../js/tinymce/skins/lightgray/content.min.css',
    height: 300,
    menubar: false,
    image_advtab: true,
    branding: false,
    relative_urls: false,
    remove_script_host: false
});
BLOG = {
    uploadImageToServer: function (that) {
        // create input and insert in the DOM
        var inp = $('<input id="tinymce-uploader" type="file" name="pic" accept="image/*" style="display:none">');
        $(that.getElement()).parent().append(inp);
        var parent1 = $(that.getElement()).parent();

        // add the image upload button to the editor toolbar
        that.addButton('imageupload', {
            text: 'Local',
            icon: 'image',
            onclick: function (e) { // when toolbar button is clicked, open file select modal
                inp.trigger('click');
            }
        });

        // when a file is selected, upload it to the server
        inp.on("change", function (e) {
            BLOG.uploadFile(this, that);
        });
    },
    uploadFile: function (that, editor) {
        var file_data = $(that).prop('files')[0];
        var data = new FormData();
        data.append('file', file_data);

        $.ajax({
            url: SITE_URL + 'blogs/uploadBlogImage',
            type: 'POST',
            data: data,
            processData: false, // Don't process the files
            contentType: false, // Set content type to false as jQuery will tell the server its a query string request
            success: function (data, textStatus, jqXHR) {
                data = JSON.parse(data);
                editor.insertContent('<img class="content-img" src="' + data.url + '"/>');
            },
            error: function (jqXHR, textStatus, errorThrown) {
                if (jqXHR.responseText) {
                    errors = JSON.parse(jqXHR.responseText).errors
                    alert('Error uploading image: ' + errors.join(", ") + '. Make sure the file is an image and has extension jpg/jpeg/png.');
                }
            }
        });
    },
    voteBlog: function (that) {
        var vtype = $(that).attr('vtype');
        var bId = $(that).attr('bid');
        $.ajax({
            url: SITE_URL + "blogs/voteBlog",
            dataType: "json",
            type: 'POST',
            data: {
                vtype: vtype,
                bId: bId
            },
            success: function (response) {
                if (response.type == 'success') {
                    $(that).closest('div.row').find('.upcount').html(response.upvotes);
                    $(that).closest('div.row').find('.downcount').html(response.downvotes);
                } else if (response.type == 'login') {
                    window.location.replace(SITE_URL + "user");
                }
            }
        });
    },
    addComment: function (that) {
        var formData = $(that).serializeArray();
        var hashes = window.location.href.slice(window.location.href.indexOf('?') + 1);
        var token = hashes.substr(hashes.indexOf("=") + 1);
        formData.push({name: 'blogId', value: token});
        $.ajax({
            url: SITE_URL + "blogs/postComment",
            dataType: "json",
            type: 'POST',
            data: formData,
            success: function (response) {
                if (response.type == 'success') {
                    location.reload();
                } else if (response.type == 'login') {
                    window.location.replace(SITE_URL + "user");
                }
            }
        });
    },
    viewReply: function (that) {
        $(that).closest('div').find('#replyForm').toggle();
    },
    deleteComment: function (that) {
        var cmnt_id = $(that).attr('c_data');
        $.ajax({
            url: SITE_URL + "blogs/delComment",
            dataType: "json",
            type: 'POST',
            data: {
                cmnt_id: cmnt_id
            },
            success: function (response) {
                if (response.type == 'success') {
                    location.reload();
                }
            }
        });
    },
    loadBlog: function (that) {
        var navType = $(that).attr('type');
        var curBlogId = $(that).attr('b_data');
        if (navType == 'next') {

        } else if (navType == 'prev') {

        }
    },
    voteComment: function (that) {
        var type = $(that).attr('type');
        var cmnt_id = $(that).attr('c_data');
        $.ajax({
            url: SITE_URL + "blogs/voteComment",
            dataType: "json",
            type: 'POST',
            data: {
                cmnt_id: cmnt_id,
                type: type
            },
            success: function (response) {
                if (response.type == 'success') {
                    $(that).closest('div.row').find('.upcount').html(response.upvotes);
                    $(that).closest('div.row').find('.downcount').html(response.downvotes);
                } else if (response.type == 'login') {
                    window.location.replace(SITE_URL + "user");
                }
            }
        });
    },
    checkUserLogin: function () {
        $.ajax({
            url: SITE_URL + "blogs/voteComment",
            dataType: "json",
            type: 'POST',
            data: {
                cmnt_id: cmnt_id,
                type: type
            },
            success: function (response) {
                if (response.type == 'success') {
                    location.reload();
                }
            }
        });
    },
    saveUpdateBlog: function (that) {
        var formData = $(that).serialize();
        $.ajax({
            url: SITE_URL + "blogs/saveBlog",
            dataType: "json",
            type: 'POST',
            data: formData,
            success: function (response) {
                if (response.type == 'success') {
                    redirect('blogs');
                } else if (response.type == 'login') {
                    window.location.replace(SITE_URL + "user");
                } else {
                    AlertMessage.error(response.message);
                    return false;
                }
            },
            error: function (error) {
                ajaxError(error);
            }
        });
    },
    viewEditForm: function (that) {
        $(that).closest('li').find('span:first').toggle();
        $(that).closest('li').find('.editComment:first').toggle();
    },
    updateComment: function (that) {
        var formData = $(that).serialize();
        $.ajax({
            url: SITE_URL + "blogs/updateComment",
            dataType: "json",
            type: 'POST',
            data: formData,
            success: function (response) {
                if (response.type == 'success') {
                    location.reload();
                }
            }
        });
    }
}

$(document).on('click', '.voteBlog', function (e) {
    e.preventDefault();
    BLOG.voteBlog(this);
});
$(document).on('submit', '#addUserComment', function (e) {
    e.preventDefault();
    BLOG.addComment(this);
});
$(document).on('click', '.replyClick', function (e) {
    e.preventDefault();
    BLOG.viewReply(this);
});
$(document).on('click', '.deleteComment', function (e) {
    e.preventDefault();
    BLOG.deleteComment(this);
});
$(document).on('click', '.navBlog', function (e) {
    e.preventDefault();
    BLOG.loadBlog(this);
});
$(document).on('click', '.voteComment', function (e) {
    e.preventDefault();
    BLOG.voteComment(this);
});
$(document).on('submit', '#addNewBlog', function (e) {
    e.preventDefault();
    BLOG.saveUpdateBlog(this);
});
$(document).on('click', '.editLink', function (e) {
    e.preventDefault();
    BLOG.viewEditForm(this);
});
$(document).on('submit', '#updateComment', function (e) {
    e.preventDefault();
    BLOG.updateComment(this);
});
$(function () {
    $('.editComment').hide();
});