ANSWER = {
    initTinyMCE: function () {
        tinymce.init({
            selector: '.userAnswerText',
            theme: 'modern',
            plugins: [
                'lists charmap',
            ],
            toolbar1: 'bold italic | alignleft aligncenter alignright alignjustify | bullist numlist',
            toolbar2: 'imageupload',
            setup: function (editor) {
                ANSWER.uploadImageToServer(editor);
            },
            content_css: SITE_URL + 'js/tinymce/skins/lightgray/content.min.css',
            height: 200,
            menubar: false,
            image_advtab: true,
            branding: false,
            relative_urls: false,
            remove_script_host: false
        });
    },
    getAnswerForm: function (that) {
        var ques_id = $(that).attr('q_data');
        var answerFormDiv = $(that).closest('div.row').find('div.answerFormDiv');
        $('#answerFormTemplate').tmpl({ques_id: ques_id}).appendTo(answerFormDiv);
        ANSWER.initTinyMCE();
        $(that).bind('click', false);
    },
    uploadImageToServer: function (that) {
        // create input and insert in the DOM
        var inp = $('<input id="tinymce-uploader" type="file" name="pic" accept="image/*" style="display:none">');
        $(that.getElement()).parent().append(inp);
        var parent1 = $(that.getElement()).parent();
        // add the image upload button to the editor toolbar
        that.addButton('imageupload', {
            text: 'Local',
            icon: 'image',
            onclick: function (e) { // when toolbar button is clicked, open file select modal
                inp.trigger('click');
            }
        });
        // when a file is selected, upload it to the server
        inp.on("change", function (e) {
            var img = $(this).prop('files')[0];
            var iSize = (img.size) / 1024;
            var size = Math.round(iSize * 100) / 100;
            if (size < 500) {
                ANSWER.uploadFile(this, that);
            } else {
                AlertMessage.error('The maximum size for an image is 500 kb. Please select a another image.');
            }
        });
    },
    uploadFile: function (that, editor) {
        var file_data = $(that).prop('files')[0];
        var data = new FormData();
        data.append('file', file_data);
        $.ajax({
            url: SITE_URL + 'answers/uploadAnswerImage',
            type: 'POST',
            data: data,
            processData: false,
            contentType: false,
            success: function (data, textStatus, jqXHR) {
                data = JSON.parse(data);
                editor.insertContent('<img class="content-img" src="' + data.url + '"/>');
            },
            error: function (jqXHR, textStatus, errorThrown) {
                if (jqXHR.responseText) {
                    errors = JSON.parse(jqXHR.responseText).errors
                    alert('Error uploading image: ' + errors.join(", ") + '. Make sure the file is an image and has extension jpg/jpeg/png.');
                }
            }
        });
    },
    saveAnswer: function (that) {
        var formData = $(that).serialize();
        $.ajax({
            url: SITE_URL + "answers/saveAnswer",
            dataType: "json",
            type: 'POST',
            data: formData,
            success: function (response) {
                Loader.hide();
                if (response.type == 'success') {
                    redirect('questions');
                } else if (response.type == 'login') {
                    window.location.replace(SITE_URL + "user");
                } else {
                    AlertMessage.error(response.message);
                }
            },
            error: function (error) {
                Loader.hide();
                ajaxError(error);
            }
        });
    }
}
$(document).on('click', '.answerLink', function (e) {
    e.preventDefault();
    ANSWER.getAnswerForm(this);
});
$(document).on('submit', '#submitAnswer', function (e) {
    e.preventDefault();
    ANSWER.saveAnswer(this);
});